@@ -14,7 +14,7 @@ knearneigh <- function(x, k=1, longlat=NULL, use_kd_tree=TRUE)
            longlat <- TRUE
         } else longlat <- FALSE
         x <- coordinates(x)[, 1:2]
-    } else {
+    } else if (inherits(x, "sf") || inherits(x, "sfc")) {
         if (inherits(x, "sf")) {
             if (is.null(row.names)) row.names <- row.names(x)
             x <- sf::st_geometry(x)
@@ -36,6 +36,8 @@ knearneigh <- function(x, k=1, longlat=NULL, use_kd_tree=TRUE)
            }
            x <- sf::st_coordinates(x)
         }
+    } else if (inherits(x, "data.frame")) {
+        x <- as.matrix(x)
     } 
     if (is.null(longlat) || !is.logical(longlat)) longlat <- FALSE
     if (!is.numeric(x)) stop("knearneigh: data non-numeric")
@@ -61,7 +63,7 @@ knearneigh <- function(x, k=1, longlat=NULL, use_kd_tree=TRUE)
 # https://github.com/r-spatial/spdep/issues/38
     zd <- any(duplicated(x)) #zerodist(SpatialPoints(x))
 # kNN() handles duplicate points
-    if (zd)  {
+    if (zd && !use_s2_ll)  {
         warning("knearneigh: identical points found")
         if (use_kd_tree) {
             warning("knearneigh: kd_tree not available for identical points")
@@ -82,6 +84,8 @@ knearneigh <- function(x, k=1, longlat=NULL, use_kd_tree=TRUE)
         if (use_s2_ll) {
             z <- s2::s2_closest_edges(s2x, s2x, k=(k+1))
             z <- lapply(z, sort)
+            if (any(!(sapply(seq_along(z), function(i) i %in% z[[i]]))))
+                stop("increase k; k must be at least as large as the largest count of identical points")
             z <- lapply(seq_along(z), function(i) setdiff(z[[i]], i))
             res <- list(nn=do.call("rbind", z), np=np, k=k,
     	        dimension=dimension, x=x)
