@@ -8,8 +8,10 @@ plot.nb <- function(x, coords, col="black", points=TRUE, add=FALSE,
 
         if (inherits(coords, "sfc")) {
             if (!inherits(coords, "sfc_POINT")) {
-                    if (inherits(coords, "sfc_POLYGON") || 
-                        inherits(coords, "sfc_MULTIPOLYGON")) 
+#                    if (inherits(coords, "sfc_POLYGON") || #144
+#                        inherits(coords, "sfc_MULTIPOLYGON")) 
+#
+                 if (all(st_dimension(coords) == 2))
                         coords <- st_point_on_surface(coords)
                     else stop("Point-conforming geometries required")
                 }
