@@ -6,12 +6,12 @@ library(spdep)
 
 ## ----echo=TRUE,eval=TRUE----------------------------------------------------------------
 library(spdep)
-nc <- st_read(system.file("shapes/sids.shp", package="spData")[1], quiet=TRUE)
-st_crs(nc) <- "+proj=longlat +datum=NAD27"
+nc <- st_read(system.file("shapes/sids.gpkg", package="spData")[1], quiet=TRUE)
+#st_crs(nc) <- "EPSG:4267"
 row.names(nc) <- as.character(nc$FIPSNO)
 
 ## ----echo=TRUE--------------------------------------------------------------------------
-sf_use_s2(FALSE)
+sf_use_s2(TRUE)
 plot(st_geometry(nc), axes=TRUE)
 text(st_coordinates(st_centroid(st_geometry(nc), of_largest_polygon=TRUE)), label=nc$FIPSNO, cex=0.5)
 
